@@ -1,10 +1,9 @@
 #include <qpdf/Pl_Buffer.hh>
 
-#include <stdexcept>
 #include <algorithm>
-#include <assert.h>
-#include <string.h>
+#include <stdexcept>
 #include <stdlib.h>
+#include <string.h>
 
 Pl_Buffer::Members::Members() :
     ready(true),
@@ -12,10 +11,6 @@ Pl_Buffer::Members::Members() :
 {
 }
 
-Pl_Buffer::Members::~Members()
-{
-}
-
 Pl_Buffer::Pl_Buffer(char const* identifier, Pipeline* next) :
     Pipeline(identifier, next),
     m(new Members())
@@ -24,33 +19,31 @@ Pl_Buffer::Pl_Buffer(char const* identifier, Pipeline* next) :
 
 Pl_Buffer::~Pl_Buffer()
 {
+    // Must be explicit and not inline -- see QPDF_DLL_CLASS in
+    // README-maintainer
 }
 
 void
-Pl_Buffer::write(unsigned char* buf, size_t len)
+Pl_Buffer::write(unsigned char const* buf, size_t len)
 {
-    if (this->m->data.get() == 0)
-    {
-        this->m->data = make_pointer_holder<Buffer>(len);
+    if (this->m->data == nullptr) {
+        this->m->data = std::make_shared<Buffer>(len);
     }
     size_t cur_size = this->m->data->getSize();
     size_t left = cur_size - this->m->total_size;
-    if (left < len)
-    {
+    if (left < len) {
         size_t new_size = std::max(this->m->total_size + len, 2 * cur_size);
-        auto b = make_pointer_holder<Buffer>(new_size);
+        auto b = std::make_shared<Buffer>(new_size);
         memcpy(b->getBuffer(), this->m->data->getBuffer(), this->m->total_size);
         this->m->data = b;
     }
-    if (len)
-    {
+    if (len) {
         memcpy(this->m->data->getBuffer() + this->m->total_size, buf, len);
         this->m->total_size += len;
     }
     this->m->ready = false;
 
-    if (getNext(true))
-    {
+    if (getNext(true)) {
         getNext()->write(buf, len);
     }
 }
@@ -59,8 +52,7 @@ void
 Pl_Buffer::finish()
 {
     this->m->ready = true;
-    if (getNext(true))
-    {
+    if (getNext(true)) {
         getNext()->finish();
     }
 }
@@ -68,45 +60,39 @@ Pl_Buffer::finish()
 Buffer*
 Pl_Buffer::getBuffer()
 {
-    if (! this->m->ready)
-    {
+    if (!this->m->ready) {
         throw std::logic_error("Pl_Buffer::getBuffer() called when not ready");
     }
 
     Buffer* b = new Buffer(this->m->total_size);
-    if (this->m->total_size > 0)
-    {
+    if (this->m->total_size > 0) {
         unsigned char* p = b->getBuffer();
         memcpy(p, this->m->data->getBuffer(), this->m->total_size);
     }
-    this->m = PointerHolder<Members>(new Members());
+    this->m = std::shared_ptr<Members>(new Members());
     return b;
 }
 
-PointerHolder<Buffer>
+std::shared_ptr<Buffer>
 Pl_Buffer::getBufferSharedPointer()
 {
-    return PointerHolder<Buffer>(getBuffer());
+    return std::shared_ptr<Buffer>(getBuffer());
 }
 
 void
-Pl_Buffer::getMallocBuffer(unsigned char **buf, size_t* len)
+Pl_Buffer::getMallocBuffer(unsigned char** buf, size_t* len)
 {
-    if (! this->m->ready)
-    {
+    if (!this->m->ready) {
         throw std::logic_error(
             "Pl_Buffer::getMallocBuffer() called when not ready");
     }
 
     *len = this->m->total_size;
-    if (this->m->total_size > 0)
-    {
+    if (this->m->total_size > 0) {
         *buf = reinterpret_cast<unsigned char*>(malloc(this->m->total_size));
         memcpy(*buf, this->m->data->getBuffer(), this->m->total_size);
-    }
-    else
-    {
+    } else {
         *buf = nullptr;
     }
-    this->m = PointerHolder<Members>(new Members());
+    this->m = std::shared_ptr<Members>(new Members());
 }
