@@ -1,28 +1,22 @@
 #include <qpdf/QPDFEFStreamObjectHelper.hh>
 
+#include <qpdf/Pl_Count.hh>
+#include <qpdf/Pl_Discard.hh>
+#include <qpdf/Pl_MD5.hh>
 #include <qpdf/QIntC.hh>
 #include <qpdf/QUtil.hh>
-#include <qpdf/Pl_Count.hh>
-#include <qpdf/Pl_MD5.hh>
-#include <qpdf/Pl_Discard.hh>
 
-QPDFEFStreamObjectHelper::QPDFEFStreamObjectHelper(
-    QPDFObjectHandle oh) :
+QPDFEFStreamObjectHelper::QPDFEFStreamObjectHelper(QPDFObjectHandle oh) :
     QPDFObjectHelper(oh),
     m(new Members())
 {
 }
 
-QPDFEFStreamObjectHelper::Members::Members()
-{
-}
-
 QPDFObjectHandle
 QPDFEFStreamObjectHelper::getParam(std::string const& pkey)
 {
     auto params = this->oh.getDict().getKey("/Params");
-    if (params.isDictionary())
-    {
+    if (params.isDictionary()) {
         return params.getKey(pkey);
     }
     return QPDFObjectHandle::newNull();
@@ -33,10 +27,9 @@ QPDFEFStreamObjectHelper::setParam(
     std::string const& pkey, QPDFObjectHandle const& pval)
 {
     auto params = this->oh.getDict().getKey("/Params");
-    if (! params.isDictionary())
-    {
-        params = QPDFObjectHandle::newDictionary();
-        this->oh.getDict().replaceKey("/Params", params);
+    if (!params.isDictionary()) {
+        params = this->oh.getDict().replaceKeyAndGetNew(
+            "/Params", QPDFObjectHandle::newDictionary());
     }
     params.replaceKey(pkey, pval);
 }
@@ -45,8 +38,7 @@ std::string
 QPDFEFStreamObjectHelper::getCreationDate()
 {
     auto val = getParam("/CreationDate");
-    if (val.isString())
-    {
+    if (val.isString()) {
         return val.getUTF8Value();
     }
     return "";
@@ -56,8 +48,7 @@ std::string
 QPDFEFStreamObjectHelper::getModDate()
 {
     auto val = getParam("/ModDate");
-    if (val.isString())
-    {
+    if (val.isString()) {
         return val.getUTF8Value();
     }
     return "";
@@ -67,8 +58,7 @@ size_t
 QPDFEFStreamObjectHelper::getSize()
 {
     auto val = getParam("/Size");
-    if (val.isInteger())
-    {
+    if (val.isInteger()) {
         return QIntC::to_size(val.getUIntValueAsUInt());
     }
     return 0;
@@ -78,11 +68,9 @@ std::string
 QPDFEFStreamObjectHelper::getSubtype()
 {
     auto val = this->oh.getDict().getKey("/Subtype");
-    if (val.isName())
-    {
+    if (val.isName()) {
         auto n = val.getName();
-        if (n.length() > 1)
-        {
+        if (n.length() > 1) {
             return n.substr(1);
         }
     }
@@ -93,8 +81,7 @@ std::string
 QPDFEFStreamObjectHelper::getChecksum()
 {
     auto val = getParam("/CheckSum");
-    if (val.isString())
-    {
+    if (val.isString()) {
         return val.getStringValue();
     }
     return "";
@@ -102,14 +89,13 @@ QPDFEFStreamObjectHelper::getChecksum()
 
 QPDFEFStreamObjectHelper
 QPDFEFStreamObjectHelper::createEFStream(
-    QPDF& qpdf, PointerHolder<Buffer> data)
+    QPDF& qpdf, std::shared_ptr<Buffer> data)
 {
     return newFromStream(QPDFObjectHandle::newStream(&qpdf, data));
 }
 
 QPDFEFStreamObjectHelper
-QPDFEFStreamObjectHelper::createEFStream(
-    QPDF& qpdf, std::string const& data)
+QPDFEFStreamObjectHelper::createEFStream(QPDF& qpdf, std::string const& data)
 {
     return newFromStream(QPDFObjectHandle::newStream(&qpdf, data));
 }
@@ -119,9 +105,8 @@ QPDFEFStreamObjectHelper::createEFStream(
     QPDF& qpdf, std::function<void(Pipeline*)> provider)
 {
     auto stream = QPDFObjectHandle::newStream(&qpdf);
-    stream.replaceStreamData(provider,
-                             QPDFObjectHandle::newNull(),
-                             QPDFObjectHandle::newNull());
+    stream.replaceStreamData(
+        provider, QPDFObjectHandle::newNull(), QPDFObjectHandle::newNull());
     return newFromStream(stream);
 }
 
@@ -154,20 +139,19 @@ QPDFEFStreamObjectHelper::newFromStream(QPDFObjectHandle stream)
     stream.getDict().replaceKey(
         "/Type", QPDFObjectHandle::newName("/EmbeddedFile"));
     Pl_Discard discard;
+    // The PDF spec specifies use of MD5 here and notes that it is not
+    // to be used for security. MD5 is known to be insecure.
     Pl_MD5 md5("EF md5", &discard);
     Pl_Count count("EF size", &md5);
-    if (! stream.pipeStreamData(&count, nullptr, 0, qpdf_dl_all))
-    {
+    if (!stream.pipeStreamData(&count, nullptr, 0, qpdf_dl_all)) {
         stream.warnIfPossible(
             "unable to get stream data for new embedded file stream");
-    }
-    else
-    {
+    } else {
         result.setParam(
             "/Size", QPDFObjectHandle::newInteger(count.getCount()));
         result.setParam(
-            "/CheckSum", QPDFObjectHandle::newString(
-                QUtil::hex_decode(md5.getHexDigest())));
+            "/CheckSum",
+            QPDFObjectHandle::newString(QUtil::hex_decode(md5.getHexDigest())));
     }
     return result;
 }
