@@ -3,12 +3,21 @@
 #include <qpdf/QUtil.hh>
 
 QPDF_Integer::QPDF_Integer(long long val) :
+    QPDFValue(::ot_integer, "integer"),
     val(val)
 {
 }
 
-QPDF_Integer::~QPDF_Integer()
+std::shared_ptr<QPDFObject>
+QPDF_Integer::create(long long value)
 {
+    return do_create(new QPDF_Integer(value));
+}
+
+std::shared_ptr<QPDFObject>
+QPDF_Integer::shallowCopy()
+{
+    return create(val);
 }
 
 std::string
@@ -18,23 +27,11 @@ QPDF_Integer::unparse()
 }
 
 JSON
-QPDF_Integer::getJSON()
+QPDF_Integer::getJSON(int json_version)
 {
     return JSON::makeInt(this->val);
 }
 
-QPDFObject::object_type_e
-QPDF_Integer::getTypeCode() const
-{
-    return QPDFObject::ot_integer;
-}
-
-char const*
-QPDF_Integer::getTypeName() const
-{
-    return "integer";
-}
-
 long long
 QPDF_Integer::getVal() const
 {
