@@ -1,10 +1,8 @@
 #include <qpdf/QPDF.hh>
 
-#include <assert.h>
-
+#include <qpdf/QPDFExc.hh>
 #include <qpdf/QTC.hh>
 #include <qpdf/QUtil.hh>
-#include <qpdf/QPDFExc.hh>
 
 // In support of page manipulation APIs, these methods internally
 // maintain state about pages in a pair of data structures: all_pages,
@@ -23,6 +21,8 @@
 // reference is returned, the current code is fine and does not need
 // to be replaced. A partial implementation of QPDFPagesTree is in
 // github in attic in case there is ever a reason to resurrect it.
+// There are additional notes in README-maintainer, which also refers
+// to this comment.
 
 // The goal of this code is to ensure that the all_pages vector, which
 // users may have a reference to, and the pageobj_to_pages_pos map,
@@ -53,25 +53,22 @@ QPDF::getAllPages()
 {
     // Note that pushInheritedAttributesToPage may also be used to
     // initialize this->m->all_pages.
-    if (this->m->all_pages.empty())
-    {
+    if (this->m->all_pages.empty()) {
+        this->m->ever_called_get_all_pages = true;
         std::set<QPDFObjGen> visited;
         std::set<QPDFObjGen> seen;
         QPDFObjectHandle pages = getRoot().getKey("/Pages");
         bool warned = false;
         bool changed_pages = false;
-        while (pages.isDictionary() && pages.hasKey("/Parent"))
-        {
-            if (seen.count(pages.getObjGen()))
-            {
+        while (pages.isDictionary() && pages.hasKey("/Parent")) {
+            if (seen.count(pages.getObjGen())) {
                 // loop -- will be detected again and reported later
                 break;
             }
             // Files have been found in the wild where /Pages in the
             // catalog points to the first page. Try to work around
             // this and similar cases with this heuristic.
-            if (! warned)
-            {
+            if (!warned) {
                 getRoot().warnIfPossible(
                     "document page tree root (root -> /Pages) doesn't point"
                     " to the root of the page tree; attempting to correct");
@@ -81,74 +78,73 @@ QPDF::getAllPages()
             changed_pages = true;
             pages = pages.getKey("/Parent");
         }
-        if (changed_pages)
-        {
+        if (changed_pages) {
             getRoot().replaceKey("/Pages", pages);
         }
         seen.clear();
-        getAllPagesInternal(pages, this->m->all_pages, visited, seen);
+        if (pages.hasKey("/Kids")) {
+            // Ensure we actually found a /Pages object.
+            getAllPagesInternal(pages, visited, seen);
+        }
     }
     return this->m->all_pages;
 }
 
 void
-QPDF::getAllPagesInternal(QPDFObjectHandle cur_node,
-                          std::vector<QPDFObjectHandle>& result,
-                          std::set<QPDFObjGen>& visited,
-                          std::set<QPDFObjGen>& seen)
+QPDF::getAllPagesInternal(
+    QPDFObjectHandle cur_node,
+    std::set<QPDFObjGen>& visited,
+    std::set<QPDFObjGen>& seen)
 {
-    QPDFObjGen this_og = cur_node.getObjGen();
-    if (visited.count(this_og) > 0)
-    {
+    QPDFObjGen cur_node_og = cur_node.getObjGen();
+    if (visited.count(cur_node_og) > 0) {
         throw QPDFExc(
-            qpdf_e_pages, this->m->file->getName(),
-            this->m->last_object_description, 0,
+            qpdf_e_pages,
+            this->m->file->getName(),
+            this->m->last_object_description,
+            0,
             "Loop detected in /Pages structure (getAllPages)");
     }
-    visited.insert(this_og);
-    std::string wanted_type;
-    if (cur_node.hasKey("/Kids"))
-    {
-        wanted_type = "/Pages";
-        QPDFObjectHandle kids = cur_node.getKey("/Kids");
-        int n = kids.getArrayNItems();
-        for (int i = 0; i < n; ++i)
-        {
-            QPDFObjectHandle kid = kids.getArrayItem(i);
-            if (! kid.isIndirect())
-            {
+    visited.insert(cur_node_og);
+    if (!cur_node.isDictionaryOfType("/Pages")) {
+        cur_node.warnIfPossible(
+            "/Type key should be /Pages but is not; overriding");
+        cur_node.replaceKey("/Type", "/Pages"_qpdf);
+    }
+    auto kids = cur_node.getKey("/Kids");
+    int n = kids.getArrayNItems();
+    for (int i = 0; i < n; ++i) {
+        auto kid = kids.getArrayItem(i);
+        if (kid.hasKey("/Kids")) {
+            getAllPagesInternal(kid, visited, seen);
+        } else {
+            if (!kid.isIndirect()) {
                 QTC::TC("qpdf", "QPDF handle direct page object");
+                cur_node.warnIfPossible(
+                    "kid " + QUtil::int_to_string(i) +
+                    " (from 0) is direct; converting to indirect");
                 kid = makeIndirectObject(kid);
                 kids.setArrayItem(i, kid);
-            }
-            else if (seen.count(kid.getObjGen()))
-            {
+            } else if (seen.count(kid.getObjGen())) {
                 // Make a copy of the page. This does the same as
                 // shallowCopyPage in QPDFPageObjectHelper.
                 QTC::TC("qpdf", "QPDF resolve duplicated page object");
+                cur_node.warnIfPossible(
+                    "kid " + QUtil::int_to_string(i) +
+                    " (from 0) appears more than once in the pages tree;"
+                    " creating a new page object as a copy");
                 kid = makeIndirectObject(QPDFObjectHandle(kid).shallowCopy());
                 kids.setArrayItem(i, kid);
             }
-            getAllPagesInternal(kid, result, visited, seen);
+            if (!kid.isDictionaryOfType("/Page")) {
+                kid.warnIfPossible(
+                    "/Type key should be /Page but is not; overriding");
+                kid.replaceKey("/Type", "/Page"_qpdf);
+            }
+            seen.insert(kid.getObjGen());
+            m->all_pages.push_back(kid);
         }
     }
-    else
-    {
-        wanted_type = "/Page";
-        seen.insert(this_og);
-        result.push_back(cur_node);
-    }
-
-    if (! cur_node.isDictionaryOfType(wanted_type))
-    {
-        warn(QPDFExc(qpdf_e_damaged_pdf, this->m->file->getName(),
-                     "page tree node",
-                     this->m->file->getLastOffset(),
-                     "/Type key should be " + wanted_type +
-                     " but is not; overriding"));
-        cur_node.replaceKey("/Type", QPDFObjectHandle::newName(wanted_type));
-    }
-    visited.erase(this_og);
 }
 
 void
@@ -171,8 +167,7 @@ QPDF::flattenPagesTree()
     // If not already done, flatten the /Pages structure and
     // initialize pageobj_to_pages_pos.
 
-    if (! this->m->pageobj_to_pages_pos.empty())
-    {
+    if (!this->m->pageobj_to_pages_pos.empty()) {
         return;
     }
 
@@ -183,8 +178,7 @@ QPDF::flattenPagesTree()
     QPDFObjectHandle pages = getRoot().getKey("/Pages");
 
     size_t const len = this->m->all_pages.size();
-    for (size_t pos = 0; pos < len; ++pos)
-    {
+    for (size_t pos = 0; pos < len; ++pos) {
         // Populate pageobj_to_pages_pos and fix parent pointer. There
         // should be no duplicates at this point because
         // pushInheritedAttributesToPage calls getAllPages which
@@ -195,35 +189,33 @@ QPDF::flattenPagesTree()
 
     pages.replaceKey("/Kids", QPDFObjectHandle::newArray(this->m->all_pages));
     // /Count has not changed
-    if (pages.getKey("/Count").getUIntValue() != len)
-    {
+    if (pages.getKey("/Count").getUIntValue() != len) {
         throw std::runtime_error("/Count is wrong after flattening pages tree");
     }
 }
 
 void
-QPDF::insertPageobjToPage(QPDFObjectHandle const& obj, int pos,
-                          bool check_duplicate)
+QPDF::insertPageobjToPage(
+    QPDFObjectHandle const& obj, int pos, bool check_duplicate)
 {
     QPDFObjGen og(obj.getObjGen());
-    if (check_duplicate)
-    {
-        if (! this->m->pageobj_to_pages_pos.insert(
-                std::make_pair(og, pos)).second)
-        {
+    if (check_duplicate) {
+        if (!this->m->pageobj_to_pages_pos.insert(std::make_pair(og, pos))
+                 .second) {
             // The library never calls insertPageobjToPage in a way
             // that causes this to happen.
-            setLastObjectDescription("page " + QUtil::int_to_string(pos) +
-                                     " (numbered from zero)",
-                                     og.getObj(), og.getGen());
-            throw QPDFExc(qpdf_e_pages, this->m->file->getName(),
-                          this->m->last_object_description, 0,
-                          "duplicate page reference found;"
-                          " this would cause loss of data");
+            setLastObjectDescription(
+                "page " + QUtil::int_to_string(pos) + " (numbered from zero)",
+                og);
+            throw QPDFExc(
+                qpdf_e_pages,
+                this->m->file->getName(),
+                this->m->last_object_description,
+                0,
+                "duplicate page reference found;"
+                " this would cause loss of data");
         }
-    }
-    else
-    {
+    } else {
         this->m->pageobj_to_pages_pos[og] = pos;
     }
 }
@@ -236,45 +228,45 @@ QPDF::insertPage(QPDFObjectHandle newpage, int pos)
 
     flattenPagesTree();
 
-    if (! newpage.isIndirect())
-    {
+    if (!newpage.isIndirect()) {
         QTC::TC("qpdf", "QPDF insert non-indirect page");
         newpage = makeIndirectObject(newpage);
-    }
-    else if (newpage.getOwningQPDF() != this)
-    {
+    } else if (newpage.getOwningQPDF() != this) {
         QTC::TC("qpdf", "QPDF insert foreign page");
-        newpage.getOwningQPDF()->pushInheritedAttributesToPage();
+        newpage.getQPDF().pushInheritedAttributesToPage();
         newpage = copyForeignObject(newpage);
-    }
-    else
-    {
+    } else {
         QTC::TC("qpdf", "QPDF insert indirect page");
     }
 
-    QTC::TC("qpdf", "QPDF insert page",
-            (pos == 0) ? 0 :                      // insert at beginning
-            (pos == QIntC::to_int(this->m->all_pages.size())) ? 1 : // at end
-            2);                                   // insert in middle
+    if ((pos < 0) || (QIntC::to_size(pos) > this->m->all_pages.size())) {
+        throw std::runtime_error(
+            "QPDF::insertPage called with pos out of range");
+    }
+
+    QTC::TC(
+        "qpdf",
+        "QPDF insert page",
+        (pos == 0) ? 0 : // insert at beginning
+            (pos == QIntC::to_int(this->m->all_pages.size())) ? 1
+                                                              : // at end
+            2); // insert in middle
 
     auto og = newpage.getObjGen();
-    if (this->m->pageobj_to_pages_pos.count(og))
-    {
+    if (this->m->pageobj_to_pages_pos.count(og)) {
         QTC::TC("qpdf", "QPDF resolve duplicated page in insert");
         newpage = makeIndirectObject(QPDFObjectHandle(newpage).shallowCopy());
     }
 
     QPDFObjectHandle pages = getRoot().getKey("/Pages");
     QPDFObjectHandle kids = pages.getKey("/Kids");
-    assert ((pos >= 0) && (QIntC::to_size(pos) <= this->m->all_pages.size()));
 
     newpage.replaceKey("/Parent", pages);
     kids.insertItem(pos, newpage);
     int npages = kids.getArrayNItems();
     pages.replaceKey("/Count", QPDFObjectHandle::newInteger(npages));
     this->m->all_pages.insert(this->m->all_pages.begin() + pos, newpage);
-    for (int i = pos + 1; i < npages; ++i)
-    {
+    for (int i = pos + 1; i < npages; ++i) {
         insertPageobjToPage(this->m->all_pages.at(toS(i)), i, false);
     }
     insertPageobjToPage(newpage, pos, true);
@@ -284,10 +276,13 @@ void
 QPDF::removePage(QPDFObjectHandle page)
 {
     int pos = findPage(page); // also ensures flat /Pages
-    QTC::TC("qpdf", "QPDF remove page",
-            (pos == 0) ? 0 :                            // remove at beginning
-            (pos == QIntC::to_int(this->m->all_pages.size() - 1)) ? 1 : // end
-            2);                                         // remove in middle
+    QTC::TC(
+        "qpdf",
+        "QPDF remove page",
+        (pos == 0) ? 0 : // remove at beginning
+            (pos == QIntC::to_int(this->m->all_pages.size() - 1)) ? 1
+                                                                  : // end
+            2); // remove in middle
 
     QPDFObjectHandle pages = getRoot().getKey("/Pages");
     QPDFObjectHandle kids = pages.getKey("/Kids");
@@ -297,19 +292,16 @@ QPDF::removePage(QPDFObjectHandle page)
     pages.replaceKey("/Count", QPDFObjectHandle::newInteger(npages));
     this->m->all_pages.erase(this->m->all_pages.begin() + pos);
     this->m->pageobj_to_pages_pos.erase(page.getObjGen());
-    for (int i = pos; i < npages; ++i)
-    {
+    for (int i = pos; i < npages; ++i) {
         insertPageobjToPage(this->m->all_pages.at(toS(i)), i, false);
     }
 }
 
 void
-QPDF::addPageAt(QPDFObjectHandle newpage, bool before,
-                QPDFObjectHandle refpage)
+QPDF::addPageAt(QPDFObjectHandle newpage, bool before, QPDFObjectHandle refpage)
 {
     int refpos = findPage(refpage);
-    if (! before)
-    {
+    if (!before) {
         ++refpos;
     }
     insertPage(newpage, refpos);
@@ -318,12 +310,9 @@ QPDF::addPageAt(QPDFObjectHandle newpage, bool before,
 void
 QPDF::addPage(QPDFObjectHandle newpage, bool first)
 {
-    if (first)
-    {
+    if (first) {
         insertPage(newpage, 0);
-    }
-    else
-    {
+    } else {
         insertPage(
             newpage,
             getRoot().getKey("/Pages").getKey("/Count").getIntValueAsInt());
@@ -340,15 +329,16 @@ int
 QPDF::findPage(QPDFObjGen const& og)
 {
     flattenPagesTree();
-    std::map<QPDFObjGen, int>::iterator it =
-        this->m->pageobj_to_pages_pos.find(og);
-    if (it == this->m->pageobj_to_pages_pos.end())
-    {
+    auto it = this->m->pageobj_to_pages_pos.find(og);
+    if (it == this->m->pageobj_to_pages_pos.end()) {
         QTC::TC("qpdf", "QPDF_pages findPage not found");
-        setLastObjectDescription("page object", og.getObj(), og.getGen());
-        throw QPDFExc(qpdf_e_pages, this->m->file->getName(),
-                      this->m->last_object_description, 0,
-                      "page object not referenced in /Pages tree");
+        setLastObjectDescription("page object", og);
+        throw QPDFExc(
+            qpdf_e_pages,
+            this->m->file->getName(),
+            this->m->last_object_description,
+            0,
+            "page object not referenced in /Pages tree");
     }
     return (*it).second;
 }
